<?php

namespace App\Controller;

use App\Entity\Commentaire;
use App\Entity\Realisateur;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\HttpFoundation\Request;
use App\Entity\Genre;
use App\Form\CommentaireType;
use App\Repository\CommentaireRepository;
use App\Repository\FilmRepository;
use App\Repository\GenreRepository;
use App\Repository\RealisateurRepository;
use App\Service\CommentaireManager;
use App\Service\OptionsManager;
use Symfony\Bundle\SecurityBundle\Security;
use Symfony\Component\HttpFoundation\Response;

class VideothequeListController extends FilmAbstractController
{
	#[Route("/", name: "videotheque_liste")]
	public function listeAction(Request $request, FilmRepository $filmRepository, OptionsManager $options): Response
	{
        $filtersForm = $this->formPagination($request);
        $listeFilms = $filmRepository->findTous($filtersForm->getData()->toArray());
        dump($filtersForm->getData());

		return $this->render('videotheque/liste_'.$options->vue().'.html.twig', array(
            'listeFilms'	=>	$listeFilms,
            'titre'         =>  'Liste complète',
            'filtersForm'   =>  $filtersForm->createView()
		));
    }

    #[Route("/maliste", name:"videothequepersonnelle_maliste")]
	public function maListeAction (Request $request, OptionsManager $options, FilmRepository $filmRepository): Response
    {
        $filtersForm = $this->formPagination($request);
        $listeFilms = $filmRepository->findTousFavoritesByUser($this->getUser(), $filtersForm->getData()->toArray());
        return $this->render('videotheque/liste_'.$options->vue().'.html.twig', array(
            'listeFilms'    =>  $listeFilms,
            'titre'         =>  'Ma liste de films à voir',
            'filtersForm'   => $filtersForm->createView()
        ));
    }

    #[Route("/prochaines-sorties", name: "prochaines_sorties")]
    public function prochainesSorties(FilmRepository $repo, OptionsManager $options): Response
    {
        $listeFilms = $repo->findProchaines();

        return $this->render('videotheque/liste_'.$options->vue().'.html.twig', array(
            'listeFilms'	=>	$listeFilms,
            'titre'         =>  'Prochaines sorties et films en salle',
		));
    }

    #[Route("/liste-by/{id}", name: "videotheque_listepargenre")]
	public function listeParGenreAction(Request $request, Genre $genre, FilmRepository $repo, OptionsManager $options): Response
    {
        $filtersForm = $this->formPagination($request);
        $films = $repo->findFilmWithGenre([$genre->getName()], $filtersForm->getData()->toArray());

        return $this->render('videotheque/liste_'.$options->vue().'.html.twig', array(
            'listeFilms'    => $films,
            'titre'         => 'Films par catégorie : '.$genre->getName(),
            'filtersForm'   => $filtersForm
        ));
    }

    #[Route("/liste-by_real/{id}", name: "videotheque_listeparreal")]
    public function  listeParRealisateurAction(Request $request, Realisateur $realisateur, FilmRepository $repo, OptionsManager $options): Response
    {
        $filtersForm = $this->formPagination($request);
        $films = $repo->findFilmWithReal([$realisateur->getNomComplet()], $filtersForm->getData()->toArray());

        return $this->render('videotheque/liste_'.$options->vue().'.html.twig', array(
            'listeFilms'    => $films,
            'titre'         => 'Films par réalisateur : '.$realisateur->getNomComplet(),
            'filtersForm'   => $filtersForm
        ));
    }

	#[Route("/fichefilm/{id}", name: "videotheque_voirfilm")]
	public function voirFilmAction(Request $request, \App\Entity\Film $film, CommentaireManager $cm, Security $security, CommentaireRepository $repo): Response
    {
        if ($security->isGranted('IS_AUTHENTICATED_REMEMBERED'))
        {
            $commentaireUser = $repo->findOneBy(array('film'=>$film, 'user'=>$this->getUser()));
            if (is_null($commentaireUser))
            {
                $commentaireUser = new Commentaire();
            }
            $form = $this->createForm(CommentaireType::class, $commentaireUser);
            $form->handleRequest($request);
            if ($form->isSubmitted() && $form->isValid())
            {
                $cm->delEditAdd($commentaireUser, $film);
                $this->addFlash('success', 'Le commentaire a été posté');
                return $this->redirectToRoute('videotheque_voirfilm', array('id' => $film->getId()));
            }
        } else {
            $form = $this->createForm(CommentaireType::class, null);
        }
        
        return $this->render('videotheque/voirfilm.html.twig', array(
            'film' => $film,
            'form'  =>  $form
        ));
    }

    #[Route("/ajax_req_realisateurs", name: "videotheque_ajax_realisateurs")]
    public function ajaxRealisateurs(Request $request, RealisateurRepository $repo): Response
    {
        $query = $request->query->get('query');
        $realisateurs = $repo->findRealisateurLike($query);
        $liste = array();
        foreach ($realisateurs as $realisateur)
        {
            $liste[] = $realisateur->getNomComplet();
        }

        return new JsonResponse($liste);
    }

    #[Route("/ajax_req_genres", name: "videotheque_ajax_genres")]
    public function ajaxGenres(Request $request, GenreRepository $repo): Response
    {
        $query = $request->query->get('query');
        $genres = $repo->findGenreLike($query);
        $liste = array();
        foreach ($genres as $genre)
        {
            $liste[] = $genre->getName();
        }
        
        return new JsonResponse($liste);
    }
}
